******************************************************************
*  REPLICATION CODE FOR                                          *
*  "THE POLITICAL ECONOMY OF PUBLIC DEBT: A LABORATORY STUDY"    *
*  BY MARCO BATTAGLINI, SALVATORE NUNNARI, AND THOMAS R. PALFREY *
*  DATE: MARCH 29, 2019                                          *
*  SOFTWARE: STATA/SE 14.2                                       *
******************************************************************

use "bnp_debtexp_29mar19.dta", clear

************
* CODEBOOK *
************

/*
VARIABLES FOR BOTH COMMITMENT AND NO COMMITMENT SESSIONS

accepted: dummy for accepted proposal
bocconi: dummy for sessions at Bocconi University
clientid: subject ID in a session
commitment: dummy for session with commitment treatment
date: experimental session date
expid: experimental session ID (chronological order, see Table 20 for details) 
groupid: group ID
index: group member ID
matchid: match ID 
p: value of parameter p in session
p_budget: total amount spent in proposal 
p1_carryover: savings in proposal 
p1_debt: debt in proposal 
pc_budget: total amount spent  in selected proposal 
pc1_carryover: savings in selected proposal 
pc1_debt: debt in selected proposal
proposer: index of proposer in round
q: value of parameter q in session
roundid: round ID
subroundid: sub-round ID 
vote: group member vote 
voteyes: dummy for group member voting yes 
yesvotes: total number of yes votes in group

VARIABLES FOR COMMITMENT SESSIONS ONLY

a1: value of parameter A in round 1 
a2: value of parameter A in round 2
p1_pgood: amount to public good in round 1 in proposal 
p1_pork0: amount to member 0 pork in round 1 in proposal
p1_pork1: amount to member 1 pork in round 1 in proposal
p1_pork2: amount to member 2 pork in round 1 in proposal
p1_pork3: amount to member 3 pork in round 1 in proposal
p1_pork4: amount to member 4 pork in round 1 in proposal
p1_porkto1: largest pork amount to other member in round 1 in proposal 
p1_porkto2: 2nd largest pork amount to other member in round 1 in proposal
p1_porkto3: 3rd largest pork amount to other member in round 1 in proposal
p1_porkto4: 4th largest pork amount to other member in round 1 in proposal
p1_porktomwc: total pork to minimal winning coalition in round 1 in proposal
p1_porktoprop: pork to proposer in round 1 in proposal 
p1_porktot: total pork in round 1 in proposal 
p2H_budget: total amount spent in round 2 and high state in proposal 
p2H_pgood: amount to public good in round 2 and high state in proposal
p2H_pork0: amount to member 0 pork in round 2 and high state in proposal
p2H_pork1: amount to member 1 pork in round 2 and high state in proposal
p2H_pork2: amount to member 2 pork in round 2 and high state in proposal
p2H_pork3: amount to member 3 pork in round 2 and high state in proposal 
p2H_pork4: amount to member 4 pork in round 2 and high state in proposal 
p2H_porkto1: largest pork amount to other member in round 2 and high state in proposal
p2H_porkto2: 2nd largest pork amount to other member in round 2 and high state in proposal
p2H_porkto3: 3rd largest pork amount to other member in round 2 and high state in proposal
p2H_porkto4: 4th largest pork amount to other member in round 2 and high state in proposal
p2H_porktomwc: total pork to minimal winning coalition in round 2 and high state in proposal
p2H_porktoprop: pork to proposer in round 2 and high state in proposal 
p2H_porktot: total pork in round 2 and high state in proposal 
p2L_budget: total amount spent in round 2 and low state in proposal 
p2L_pgood: amount to public good in round 2 and low state in proposal
p2L_pork0: amount to member 0 pork in round 2 and low state in proposal 
p2L_pork1: amount to member 1 pork in round 2 and low state in proposal  
p2L_pork2: amount to member 2 pork in round 2 and low state in proposal  
p2L_pork3: amount to member 3 pork in round 2 and low state in proposal  
p2L_pork4: amount to member 4 pork in round 2 and low state in proposal  
p2L_porkto1: largest pork amount to other member in round 2 and low state in proposal
p2L_porkto2: 2nd largest pork amount to other member in round 2 and low state in proposal 
p2L_porkto3: 3rd largest pork amount to other member in round 2 and low state in proposal 
p2L_porkto4: 4th largest pork amount to other member in round 2 and low state in proposal 
p2L_porktomwc: total pork to minimal winning coalition in round 2 and low state in proposal
p2L_porktoprop: pork to proposer in round 2 and low state in proposal 
p2L_porktot: total pork in round 2 and low state in proposal   
pc_1pgood: amount to public good in round 1 in selected proposal 
pc_1pork0: amount to member 0 pork in round 1 in selected proposal
pc_1pork1: amount to member 1 pork in round 1 in selected proposal
pc_1pork2: amount to member 2 pork in round 1 in selected proposal
pc_1pork3: amount to member 3 pork in round 1 in selected proposal
pc_1pork4: amount to member 4 pork in round 1 in selected proposal
pc_1porkto1: largest pork amount to other member in round 1 in selected proposal 
pc_1porkto2: 2nd largest pork amount to other member in round 1 in selected proposal
pc_1porkto3: 3rd largest pork amount to other member in round 1 in selected proposal
pc_1porkto4: 4th largest pork amount to other member in round 1 in selected proposal
pc_1porktomwc: total pork to minimal winning coalition in round 1 in selected proposal
pc_1porktoprop: pork to proposer in round 1 in selected proposal 
pc_1porktot: total pork in round 1 in selected proposal 
pc_2H_budget: total amount spent in round 2 and high state in selected proposal 
pc_2H_pgood: amount to public good in round 2 and high state in selected proposal
pc_2H_pork0: amount to member 0 pork in round 2 and high state in selected proposal
pc_2H_pork1: amount to member 1 pork in round 2 and high state in selected proposal
pc_2H_pork2: amount to member 2 pork in round 2 and high state in selected proposal
pc_2H_pork3: amount to member 3 pork in round 2 and high state in selected proposal 
pc_2H_pork4: amount to member 4 pork in round 2 and high state in selected proposal 
pc_2H_porkto1: largest pork amount to other member in round 2 and high state in selected proposal
pc_2H_porkto2: 2nd largest pork amount to other member in round 2 and high state in selected proposal
pc_2H_porkto3: 3rd largest pork amount to other member in round 2 and high state in selected proposal
pc_2H_porkto4: 4th largest pork amount to other member in round 2 and high state in selected proposal
pc_2H_porktomwc: total pork to minimal winning coalition in round 2 and high state in selected proposal
pc_2H_porktoprop: pork to proposer in round 2 and high state in selected proposal 
pc_2H_porktot: total pork in round 2 and high state in selected proposal 
pc_2L_budget: total amount spent in round 2 and low state in selected proposal 
pc_2L_pgood: amount to public good in round 2 and low state in selected proposal
pc_2L_pork0: amount to member 0 pork in round 2 and low state in selected proposal 
pc_2L_pork1: amount to member 1 pork in round 2 and low state in selected proposal  
pc_2L_pork2: amount to member 2 pork in round 2 and low state in selected proposal  
pc_2L_pork3: amount to member 3 pork in round 2 and low state in selected proposal  
pc_2L_pork4: amount to member 4 pork in round 2 and low state in selected proposal  
pc_2L_porkto1: largest pork amount to other member in round 2 and low state in selected proposal
pc_2L_porkto2: 2nd largest pork amount to other member in round 2 and low state in selected proposal 
pc_2L_porkto3: 3rd largest pork amount to other member in round 2 and low state in selected proposal 
pc_2L_porkto4: 4th largest pork amount to other member in round 2 and low state in selected proposal 
pc_2L_porktomwc: total pork to minimal winning coalition in round 2 and low state in selected proposal
pc_2L_porktoprop: pork to proposer in round 2 and low state in selected proposal 
pc_2L_porktot: total pork in round 2 and low state in selected proposal   

VARIABLES FOR NO COMMITMENT SESSIONS ONLY

a: value of parameter A in round 
HPvsLP: dummy for high p versus low p (simple majority)
MvsS: dummy for majority versus supermajority (low p)
OvsM: dummy for oligarchy versus simple majority (low p)
OvsS: dummy for oligarchy versus super majority (low p)
p_pgood: amount to public good in proposal
p_pork0: amount to member 0 pork in proposal 
p_pork1: amount to member 1 pork in proposal  
p_pork2: amount to member 2 pork in proposal  
p_pork3: amount to member 3 pork in proposal  
p_pork4: amount to member 4 pork in proposal  
p_porkto1: largest pork amount to other member in proposal 
p_porkto2: 2nd largest pork amount to other member in proposal  
p_porkto3: 3rd largest pork amount to other member in proposal  
p_porkto4: 4th largest pork amount to other member in proposal  
p_porktomwc: pork to minimal winning coalition in proposal 
p_porktoprop: pork to proposer in proposal 
p_porktot: total pork in proposal
pc_pgood: amount to public good in selected proposal
pc_pork0: amount to member 0 pork in selected proposal 
pc_pork1: amount to member 1 pork in selected proposal  
pc_pork2: amount to member 2 pork in selected proposal  
pc_pork3: amount to member 3 pork in selected proposal  
pc_pork4: amount to member 4 pork in selected proposal  
pc_porkto1: largest pork amount to other member in selected proposal 
pc_porkto2: 2nd largest pork amount to other member in selected proposal  
pc_porkto3: 3rd largest pork amount to other member in selected proposal  
pc_porkto4: 4th largest pork amount to other member in selected proposal  
pc_porktomwc: pork to minimal winning coalition in selected proposal 
pc_porktoprop: pork to proposer in selected proposal 
pc_porktot: total pork in selected proposal

*/ 

* Table 3: Outcomes in Approved Allocations, Period 1, Comparison of Majority Rules
* Figure 2: Average Public Debt in Approved Allocation, Panel (a) Comparison of Majority Rules
* Figure 3: Average Public Good in Approved Allocations, Period 1, Panel (a) Comparison of Majority Rules

bys q: su p1_debt p_pgood p_porktoprop p_porktomwc p_porktot if commitment==0 & roundid==1 & proposer==index & accepted==1 & p=="1/2"
   
* Table 4: Outcomes in Approved Allocations, Period 1, Comparison of Economic Risk
* Figure 2: Average Public Debt in Approved Allocation, Panel (b) Comparison of Economic Risk
* Figure 3: Average Public Good in Approved Allocations, Period 1, Panel (b) Comparison of Economic Risk

bys p: su p1_debt p_pgood p_porktoprop p_porktomwc p_porktot if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==3
   
* Figure 4: Cumulative Distribution of Transfers

gen p_porktoprop_share=p_porktoprop/p_porktot if commitment==0
gen p_porkto1_share=p_porkto1/p_porktot if commitment==0
gen p_porkto2_share=p_porkto2/p_porktot if commitment==0
gen p_porkto3_share=p_porkto3/p_porktot if commitment==0
gen p_porkto4_share=p_porkto4/p_porktot if commitment==0

bys q: su p_porktoprop_share p_porkto1_share p_porkto2_share p_porkto3_share p_porkto4_share if commitment==0 & roundid==1 & proposer==index & accepted==1 & p=="1/2" 
bys p: su p_porktoprop_share p_porkto1_share p_porkto2_share p_porkto3_share p_porkto4_share if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==3

* Table 5: Average Outcomes in Approved Allocations, Period 1, All Treatments, Early (1-5) vs. Late (6+) Matches

gen earlymatch=0
replace earlymatch=1 if matchid<6 

* Columns 1 and 2
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="1/2" & earlymatch==1 & q==2
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="1/2" & earlymatch==0 & q==2

* Columns 3 and 4
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="1/2" & earlymatch==1 & q==3
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="1/2" & earlymatch==0 & q==3

* Columns 5 and 6
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="1/2" & earlymatch==1 & q==4
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="1/2" & earlymatch==0 & q==4

* Columns 7 and 8
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="11/12" & earlymatch==1
su p1_carryover p_pgood p_porktoprop p_porktomwc p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & p=="11/12" & earlymatch==0

* Wilcoxon-Mann-Whitney tests for differences between late and early matches
ranksum p1_carryover if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==2 & p=="1/2", by(earlymatch)
ranksum p1_carryover if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="1/2", by(earlymatch)
ranksum p1_carryover if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==4 & p=="1/2", by(earlymatch)
ranksum p1_carryover if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="11/12", by(earlymatch)
ranksum p_pgood if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==2 & p=="1/2", by(earlymatch)
ranksum p_pgood if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="1/2", by(earlymatch)
ranksum p_pgood if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==4 & p=="1/2", by(earlymatch)
ranksum p_pgood if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="11/12", by(earlymatch)
ranksum p_porktoprop if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==2 & p=="1/2", by(earlymatch)
ranksum p_porktoprop if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="1/2", by(earlymatch)
ranksum p_porktoprop if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==4 & p=="1/2", by(earlymatch)
ranksum p_porktoprop if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="11/12", by(earlymatch)
ranksum p_porktomwc if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==2 & p=="1/2", by(earlymatch)
ranksum p_porktomwc if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="1/2", by(earlymatch)
ranksum p_porktomwc if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==4 & p=="1/2", by(earlymatch)
ranksum p_porktomwc if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="11/12", by(earlymatch)
ranksum p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==2 & p=="1/2", by(earlymatch)
ranksum p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="1/2", by(earlymatch)
ranksum p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==4 & p=="1/2", by(earlymatch)
ranksum p_porktot if roundid==1 & commitment==0 & proposer==index & accepted==1 & q==3 & p=="11/12", by(earlymatch)

* Table 6: Proposal Types and Acceptance Rates by Treatment, Period 1

gen proposal_type = ""
replace proposal_type = "1. Positive Debt" if p_budget > 150 & roundid==1
replace proposal_type = "2. Balanced Budget" if p_budget == 150 & roundid==1
replace proposal_type = "3. Negative Debt" if p_budget < 150 & roundid==1

gen proposal_type2 = ""
replace proposal_type2 = "1. Debt \in (0,150)" if p_budget > 150 & p_budget <300 & roundid==1
replace proposal_type2 = "2. Spend Everything" if p_budget == 300 & roundid==1
replace proposal_type2 = "3. Balanced Budget" if p_budget == 150 & roundid==1
replace proposal_type2 = "4. Debt \in (0,-150)" if p_budget < 150 & p_budget > 0 & roundid==1 
replace proposal_type2 = "5. Save Everything" if p_budget == 0 & roundid==1

tab proposal_type if commitment==0 & q==2 & p=="1/2" & roundid==1
tab proposal_type if commitment==0 & q==3 & p=="1/2" & roundid==1
tab proposal_type if commitment==0 & q==4 & p=="1/2" & roundid==1
tab proposal_type if commitment==0 & q==3 & p=="11/12" & roundid==1

tab proposal_type2 if commitment==0 & q==2 & p=="1/2" & roundid==1
tab proposal_type2 if commitment==0 & q==3 & p=="1/2" & roundid==1
tab proposal_type2 if commitment==0 & q==4 & p=="1/2" & roundid==1
tab proposal_type2 if commitment==0 & q==3 & p=="11/12" & roundid==1

bys proposal_type: su accepted if commitment==0 & q==2 & p=="1/2" & roundid==1 & proposer==index
bys proposal_type: su accepted if commitment==0 & q==3 & p=="1/2" & roundid==1 & proposer==index
bys proposal_type: su accepted if commitment==0 & q==4 & p=="1/2" & roundid==1 & proposer==index
bys proposal_type: su accepted if commitment==0 & q==3 & p=="11/12" & roundid==1 & proposer==index

bys proposal_type2: su accepted if commitment==0 & q==2 & p=="1/2" & roundid==1 & proposer==index
bys proposal_type2: su accepted if commitment==0 & q==3 & p=="1/2" & roundid==1 & proposer==index
bys proposal_type2: su accepted if commitment==0 & q==4 & p=="1/2" & roundid==1 & proposer==index
bys proposal_type2: su accepted if commitment==0 & q==3 & p=="11/12" & roundid==1 & proposer==index

su accepted if commitment==0 & q==2 & p=="1/2" & roundid==1 & proposer==index
su accepted if commitment==0 & q==3 & p=="1/2" & roundid==1 & proposer==index
su accepted if commitment==0 & q==4 & p=="1/2" & roundid==1 & proposer==index
su accepted if commitment==0 & q==3 & p=="11/12" & roundid==1 & proposer==index

* Table 7: Logit Estimates of Voting Behavior, All Treatments

egen uniquesubjectid=concat(expid clientid), punct(-)

gen pc_porktome=.
replace pc_porktome=pc_pork0 if index==0
replace pc_porktome=pc_pork1 if index==1
replace pc_porktome=pc_pork2 if index==2
replace pc_porktome=pc_pork3 if index==3
replace pc_porktome=pc_pork4 if index==4

gen pc_pork0share=.
replace pc_pork0share=pc_pork0/pc_porktot if pc_porktot>0
replace pc_pork0share=0 if pc_porktot==0
gen pc_pork1share=.
replace pc_pork1share=pc_pork1/pc_porktot if pc_porktot>0
replace pc_pork1share=0 if pc_porktot==0
gen pc_pork2share=.
replace pc_pork2share=pc_pork2/pc_porktot if pc_porktot>0
replace pc_pork2share=0 if pc_porktot==0
gen pc_pork3share=.
replace pc_pork3share=pc_pork3/pc_porktot if pc_porktot>0
replace pc_pork3share=0 if pc_porktot==0
gen pc_pork4share=.
replace pc_pork4share=pc_pork4/pc_porktot if pc_porktot>0
replace pc_pork4share=0 if pc_porktot==0

gen pc_h=(pc_pork0share^2+pc_pork1share^2+pc_pork2share^2+pc_pork3share^2+pc_pork4share^2)

gen pnum=.
replace pnum=1/2 if p=="1/2"
replace pnum=11/12 if p=="11/12"

gen pc_v2carryover=.
replace pc_v2carryover=pnum*sqrt(150+pc1_carryover)+(1-pnum)*5*sqrt(150+pc1_carryover) if 150+pc1_carryover<=(q/2)^2 & a==3
replace pc_v2carryover=pnum*((150+pc1_carryover-(q/2)^2)/5+(q/2))+(1-pnum)*5*sqrt(150+pc1_carryover) if 150+pc1_carryover>(q/2)^2 & 150+pc1_carryover<=((5*q)/2)^2 & a==3
replace pc_v2carryover=pnum*((150+pc1_carryover-(q/2)^2)/5+(q/2))+(1-pnum)*((150+pc1_carryover-((5*q)/2)^2)/5+5*(q/2)) if 150+pc1_carryover>((5*q)/2)^2 & a==3

gen eq_v2carryover=.
replace eq_v2carryover=pnum*(8.8/5+1)+(1-pnum)*5*sqrt(9.8) if a==3 & q==2
replace eq_v2carryover=pnum*(26.5/5+sqrt(2.3))+(1-pnum)*5*sqrt(28.7) if a==3 & q==3 & p=="1/2"
replace eq_v2carryover=pnum*(65.4/5+sqrt(4))+(1-pnum)*5*sqrt(69.4) if a==3 & q==4
replace eq_v2carryover=pnum*sqrt(2.3)+(1-pnum)*5*sqrt(2.3) if a==3 & q==3 & p=="11/12"

gen pc_euacc=.
replace pc_euacc=pc_porktome+3*sqrt(pc_pgood)+pc_v2carryover if a==3
replace pc_euacc=pc_porktome+5*sqrt(pc_pgood) if a==5
replace pc_euacc=pc_porktome+sqrt(pc_pgood) if a==1

gen budgetthreshold=.
replace budgetthreshold=((a*q)/2)^2 if a!=3

gen pc_eurej=.
replace pc_eurej=(150+140.2-9)/5+3*sqrt(9)+eq_v2carryover if q==2 & a==3
replace pc_eurej=(150+121.3-20.3)/5+3*sqrt(20.3)+eq_v2carryover if q==3 & a==3 & p=="1/2"
replace pc_eurej=(150+80.6-36)/5+3*sqrt(36)+eq_v2carryover if q==4 & a==3
replace pc_eurej=(150+147.8-20.3)/5+3*sqrt(20.3)+eq_v2carryover if q==3 & a==3 & p=="11/12"
replace pc_eurej=a*sqrt(pc_budget) if a!=3 & pc_budget<=budgetthreshold
replace pc_eurej=(pc_budget-budgetthreshold)/5+a*sqrt(budgetthreshold) if a!=3 & pc_budget>budgetthreshold

gen pc_eudiff=pc_euacc-pc_eurej

gen pc_greed=pc_porktoprop-pc_porktome

logit voteyes pc_eudiff pc_greed pc_h if (index!=proposer & q==2 & roundid==1 & commitment==0), cluster(uniquesubjectid)
logit voteyes pc_eudiff pc_greed pc_h if (index!=proposer & q==3 & p=="1/2" & roundid==1 & commitment==0), cluster(uniquesubjectid)
logit voteyes pc_eudiff pc_greed pc_h if (index!=proposer & q==4 & roundid==1 & commitment==0), cluster(uniquesubjectid)
logit voteyes pc_eudiff pc_greed pc_h if (index!=proposer & q==3 & p=="11/12" & roundid==1 & commitment==0), cluster(uniquesubjectid)

* Table 8: Outcomes in Approved Allocations, Period 2, All Treatments, All Matches

gen p_pgood_per=.
replace p_pgood_per=p_pgood/p_budget if p_budget>0
gen p_porktoprop_per=.
replace p_porktoprop_per=p_porktoprop/p_budget if p_budget>0
gen p_porktomwc_per=.
replace p_porktomwc_per=p_porktomwc/p_budget if p_budget>0
gen p_porktot_per=.
replace p_porktot_per=p_porktot/p_budget if p_budget>0

gen eff_pgood=.
replace eff_pgood=56.25 if a==3
replace eff_pgood=6.25 if a==1 & (p_porktot+p_pgood>=6.25)
replace eff_pgood=156.25 if a==5 & (p_porktot+p_pgood>=156.25)
replace eff_pgood=p_porktot+p_pgood if a==1 & (p_porktot+p_pgood<6.25)
replace eff_pgood=p_porktot+p_pgood if a==5 & (p_porktot+p_pgood<156.25)
gen eff_pgood_per = p_pgood/eff_pgood
replace eff_pgood_per = 1 if eff_pgood == 0 & p_pgood == 0

*TOP PANEL
su p_pgood_per p_porktoprop_per p_porktomwc_per p_porktot_per eff_pgood_per if a==1 & proposer==index & accepted==1 & commitment==0 & q==2 & p_budget>0
su p_pgood_per p_porktoprop_per p_porktomwc_per p_porktot_per eff_pgood_per if a==1 & proposer==index & accepted==1 & commitment==0 & q==3 & p_budget>0
su p_pgood_per p_porktoprop_per p_porktomwc_per p_porktot_per eff_pgood_per if a==1 & proposer==index & accepted==1 & commitment==0 & q==4 & p_budget>0

*BOTTOM PANEL
su p_pgood_per p_porktoprop_per p_porktomwc_per p_porktot_per eff_pgood_per if a==5 & proposer==index & accepted==1 & commitment==0 & q==2 & p_budget>0
su p_pgood_per p_porktoprop_per p_porktomwc_per p_porktot_per eff_pgood_per if a==5 & proposer==index & accepted==1 & commitment==0 & q==3 & p_budget>0
su p_pgood_per p_porktoprop_per p_porktomwc_per p_porktot_per eff_pgood_per if a==5 & proposer==index & accepted==1 & commitment==0 & q==4 & p_budget>0

* Table 9: Proposal Types and Acceptance Rates by Treatment and Public Good Value

replace proposal_type="1. Some Pork" if p_porktot>0 & roundid==2
replace proposal_type="2. No Pork" if p_porktot==0 & roundid==2

tab proposal_type if roundid==2 & q==2 & p_budget>0 & a==1
tab proposal_type if roundid==2 & q==3 & p_budget>0 & a==1
tab proposal_type if roundid==2 & q==4 & p_budget>0 & a==1

tab proposal_type if roundid==2 & q==2 & p_budget>0 & a==5
tab proposal_type if roundid==2 & q==3 & p_budget>0 & a==5
tab proposal_type if roundid==2 & q==4 & p_budget>0 & a==5

bys proposal_type: su accepted if roundid==2 & q==2 & p_budget>0 & a==1
bys proposal_type: su accepted if roundid==2 & q==3 & p_budget>0 & a==1
bys proposal_type: su accepted if roundid==2 & q==4 & p_budget>0 & a==1

su accepted if roundid==2 & q==2 & p_budget>0 & a==1
su accepted if roundid==2 & q==3 & p_budget>0 & a==1
su accepted if roundid==2 & q==4 & p_budget>0 & a==1

bys proposal_type: su accepted if roundid==2 & q==2 & p_budget>0 & a==5
bys proposal_type: su accepted if roundid==2 & q==3 & p_budget>0 & a==5
bys proposal_type: su accepted if roundid==2 & q==4 & p_budget>0 & a==5

su accepted if roundid==2 & q==2 & p_budget>0 & a==5
su accepted if roundid==2 & q==3 & p_budget>0 & a==5
su accepted if roundid==2 & q==4 & p_budget>0 & a==5

* Table 10: Test of Intertemporal Inefficiencies

gen p_marginalvalue_pgood=.
replace p_marginalvalue_pgood=a/(2*sqrt(p_pgood)) if commitment==0 & p_pgood>0
replace p_marginalvalue_pgood=a/(2*sqrt(p_pgood+0.001)) if commitment==0 & p_pgood==0

su p_marginalvalue_pgood if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==2 
su p_marginalvalue_pgood if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==3 & p=="1/2"
su p_marginalvalue_pgood if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==4
su p_marginalvalue_pgood if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==3 & p=="11/12"

su p_marginalvalue_pgood if commitment==0 & roundid==2 & proposer==index & accepted==1 & q==2 
su p_marginalvalue_pgood if commitment==0 & roundid==2 & proposer==index & accepted==1 & q==3 & p=="1/2"
su p_marginalvalue_pgood if commitment==0 & roundid==2 & proposer==index & accepted==1 & q==4
su p_marginalvalue_pgood if commitment==0 & roundid==2 & proposer==index & accepted==1 & q==3 & p=="11/12"

ranksum p_marginalvalue_pgood if commitment==0 & proposer==index & accepted==1 & q==2, by(roundid)
ranksum p_marginalvalue_pgood if commitment==0 & proposer==index & accepted==1 & q==3 & p=="1/2", by(roundid)
ranksum p_marginalvalue_pgood if commitment==0 & proposer==index & accepted==1 & q==4, by(roundid)
ranksum p_marginalvalue_pgood if commitment==0 & proposer==index & accepted==1 & q==3 & p=="11/12", by(roundid)

* Table 11: Outcomes in Approved Allocations, Period 1 Outcomes, The Effect of Commitment

su p1_debt p_pgood p_porktoprop p_porktomwc p_porktot if commitment==0 & roundid==1 & proposer==index & accepted==1 & q==3 & p=="1/2"
su p1_debt p1_pgood p1_porktoprop p1_porktomwc p1_porktot if commitment==1 & proposer==index & accepted==1

* Table 12: Test of Intertemporal Inefficiencies, Committees with Commitment

gen p1_marginalvalue_pgood=.
replace p1_marginalvalue_pgood=3/(2*sqrt(p1_pgood)) if commitment==1 & p1_pgood>0
replace p1_marginalvalue_pgood=3/(2*sqrt(p1_pgood+0.001)) if commitment==1 & p1_pgood==0
gen p2L_marginalvalue_pgood=.
gen p2H_marginalvalue_pgood=.
replace p2L_marginalvalue_pgood=1/(2*sqrt(p2L_pgood)) if commitment==1 & p2L_pgood>0
replace p2L_marginalvalue_pgood=1/(2*sqrt(p2L_pgood+0.001)) if commitment==1 & p2L_pgood==0
replace p2H_marginalvalue_pgood=5/(2*sqrt(p2H_pgood)) if commitment==1 & p2H_pgood>0 
replace p2H_marginalvalue_pgood=5/(2*sqrt(p2H_pgood+0.001)) if commitment==1 & p2H_pgood==0
gen p2_marginalvalue_pgood = .
replace p2_marginalvalue_pgood = 0.5*p2L_marginalvalue_pgood+0.5*p2H_marginalvalue_pgood if commitment == 1
gen diff_marginalvalue_pgood = p1_marginalvalue_pgood - p2_marginalvalue_pgood

su diff_marginalvalue_pgood if commitment==1 & proposer==index & accepted==1, detail
signrank p1_marginalvalue_pgood = p2_marginalvalue_pgood if commitment==1 & proposer==index & accepted==1
signtest p1_marginalvalue_pgood = p2_marginalvalue_pgood if commitment==1 & proposer==index & accepted==1

* Table 14: P-values of Wilcoxon-Mann-Whitney Tests, Period 1 Outcomes

ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(HPvsLP)

* Table 15: P-values of T-Tests, Period 1 Outcomes

ttest p1_carryover if roundid==1 & proposer==index & accepted==1, by(OvsM)
ttest p1_carryover if roundid==1 & proposer==index & accepted==1, by(OvsS)
ttest p1_carryover if roundid==1 & proposer==index & accepted==1, by(MvsS)
ttest p1_carryover if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ttest p_pgood if roundid==1 & proposer==index & accepted==1, by(OvsM)
ttest p_pgood if roundid==1 & proposer==index & accepted==1, by(OvsS)
ttest p_pgood if roundid==1 & proposer==index & accepted==1, by(MvsS)
ttest p_pgood if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ttest p_porktoprop if roundid==1 & proposer==index & accepted==1, by(OvsM)
ttest p_porktoprop if roundid==1 & proposer==index & accepted==1, by(OvsS)
ttest p_porktoprop if roundid==1 & proposer==index & accepted==1, by(MvsS)
ttest p_porktoprop if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ttest p_porktomwc if roundid==1 & proposer==index & accepted==1, by(OvsM)
ttest p_porktomwc if roundid==1 & proposer==index & accepted==1, by(OvsS)
ttest p_porktomwc if roundid==1 & proposer==index & accepted==1, by(MvsS)
ttest p_porktomwc if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ttest p_porktot if roundid==1 & proposer==index & accepted==1, by(OvsM)
ttest p_porktot if roundid==1 & proposer==index & accepted==1, by(OvsS)
ttest p_porktot if roundid==1 & proposer==index & accepted==1, by(MvsS)
ttest p_porktot if roundid==1 & proposer==index & accepted==1, by(HPvsLP)

* Table 16: P-values of Wilcoxon-Mann-Whitney Tests, Period 2 Outcomes

* We create new treatment dummies because, for period 2 outcomes, we can pool together observations for q=3, regardless of value of p
gen OvsM_2=.
replace OvsM_2=0 if q==2
replace OvsM_2=1 if q==3
gen MvsS_2=.
replace MvsS_2=0 if q==3
replace MvsS_2=1 if q==4

* TOP PANEL
ranksum p_pgood_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktoprop_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktomwc_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktot_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_pgood_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktoprop_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktomwc_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktot_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_pgood_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktoprop_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktomwc_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktot_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
* BOTTOM PANEL
ranksum p_pgood_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktoprop_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktomwc_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktot_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_pgood_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktoprop_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktomwc_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktot_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_pgood_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktoprop_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktomwc_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktot_per if a==5 & proposer==index & accepted==1, by(MvsS_2)

* Table 17: P-values of T-Tests, Period 2 Outcomes

* TOP PANEL
ttest p_pgood_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ttest p_porktoprop_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ttest p_porktomwc_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ttest p_porktot_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ttest p_pgood_per if a==1 & proposer==index & accepted==1, by(OvsS)
ttest p_porktoprop_per if a==1 & proposer==index & accepted==1, by(OvsS)
ttest p_porktomwc_per if a==1 & proposer==index & accepted==1, by(OvsS)
ttest p_porktot_per if a==1 & proposer==index & accepted==1, by(OvsS)
ttest p_pgood_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ttest p_porktoprop_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ttest p_porktomwc_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ttest p_porktot_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
* BOTTOM PANEL
ttest p_pgood_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ttest p_porktoprop_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ttest p_porktomwc_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ttest p_porktot_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ttest p_pgood_per if a==5 & proposer==index & accepted==1, by(OvsS)
ttest p_porktoprop_per if a==5 & proposer==index & accepted==1, by(OvsS)
ttest p_porktomwc_per if a==5 & proposer==index & accepted==1, by(OvsS)
ttest p_porktot_per if a==5 & proposer==index & accepted==1, by(OvsS)
ttest p_pgood_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ttest p_porktoprop_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ttest p_porktomwc_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ttest p_porktot_per if a==5 & proposer==index & accepted==1, by(MvsS_2)

* Table 18: Outcomes in Approved Allocations, Period 1 Outcomes, The Effect of Commitment, Excluding Sessions with Subjects from Bocconi University

su p1_debt p1_pgood p1_porktoprop p1_porktomwc p1_porktot if commitment==1 & proposer==index & accepted==1 & bocconi==0

* Table 19: Test of Intertemporal Inefficiencies, Committees with Commitment, Excluding Sessions with Subjects from Bocconi University

su diff_marginalvalue_pgood if commitment==1 & proposer==index & accepted==1 & bocconi==0, detail
signrank p1_marginalvalue_pgood = p2_marginalvalue_pgood if commitment==1 & proposer==index & accepted==1 & bocconi==0
signtest p1_marginalvalue_pgood = p2_marginalvalue_pgood if commitment==1 & proposer==index & accepted==1 & bocconi==0

* Table 21: P-values of Wilcoxon-Mann-Whitney Tests, Period 1 Outcomes, Matches 1-10 Only

preserve
keep if matchid<11
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p1_carryover if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_pgood if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_porktoprop if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_porktomwc if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(OvsM)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(MvsS)
ranksum p_porktot if roundid==1 & proposer==index & accepted==1, by(HPvsLP)
restore

* Table 22: P-values of Wilcoxon-Mann-Whitney Tests, Period 2 Outcomes, Matches 1-10 Only

preserve
keep if matchid<11
* TOP PANEL
ranksum p_pgood_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktoprop_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktomwc_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktot_per if a==1 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_pgood_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktoprop_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktomwc_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktot_per if a==1 & proposer==index & accepted==1, by(OvsS)
ranksum p_pgood_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktoprop_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktomwc_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktot_per if a==1 & proposer==index & accepted==1, by(MvsS_2)
* BOTTOM PANEL
ranksum p_pgood_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktoprop_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktomwc_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_porktot_per if a==5 & proposer==index & accepted==1, by(OvsM_2)
ranksum p_pgood_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktoprop_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktomwc_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_porktot_per if a==5 & proposer==index & accepted==1, by(OvsS)
ranksum p_pgood_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktoprop_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktomwc_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
ranksum p_porktot_per if a==5 & proposer==index & accepted==1, by(MvsS_2)
restore
